@@ -1,5 +1,5 @@
 /*
- * SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2020-2023 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
@@ -10,7 +10,11 @@
 #include <KConfig>
 #include <KLocalizedString>
 #include <kldap/ldapdn.h>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <qt5keychain/keychain.h>
+#else
+#include <qt6keychain/keychain.h>
+#endif
 using namespace QKeychain;
 
 using namespace KLDAP;
@@ -19,9 +23,7 @@ LdapClientSearchConfigReadConfigJob::LdapClientSearchConfigReadConfigJob(QObject
 {
 }
 
-LdapClientSearchConfigReadConfigJob::~LdapClientSearchConfigReadConfigJob()
-{
-}
+LdapClientSearchConfigReadConfigJob::~LdapClientSearchConfigReadConfigJob() = default;
 
 bool LdapClientSearchConfigReadConfigJob::canStart() const
 {
